;(function($, window, document) {
	const fullPageDom = $('#fullpage');
	let fullpageEl = null;

	function fullPage() {
		const isMobile = ('ontouchstart' in document.documentElement) || $(window).outerWidth() < 1024;

		if (fullPageDom.hasClass('is-init')) {
			fullpageEl.reBuild(true);

			return;
		}

		// check if full-page is on page
		// and isTouchDevice
		if (fullPageDom.length && !isMobile) {

			const anchors = fullPageDom.attr('data-anchors').split(',');
			const tooltips = anchors.map((anchor) => {
				return anchor.replace('-', ' ');
			});

			fullPageDom.addClass('is-init');

			fullpageEl = new fullpage('#fullpage', {
				//options here
				dragAndMove: true,
				anchors: anchors,
				navigationTooltips: tooltips,
				navigation: true,
				scrollingSpeed: 500,
				scrollOverflow: true,
				scrollOverflowReset: false,
				scrollOverflowOptions: null,
				afterLoad: function(origin, destination) {
					changeActiveLink(destination.anchor);
					skills(destination.item);
					circleSkills(destination.item);
					if (destination.index) {
						headerHide();
					} else {
						headerVisibile();
					}
				},
				onLeave: function(origin, destination){
					changeActiveLink(destination.anchor);
					skills(destination.item);
					circleSkills(destination.item);
					if (destination.index) {
						headerHide();
					} else {
						headerVisibile();
					}
				},
			});
		}
	}

	function changeActiveLink(anchor) {
		const anchorLinks = $('a[href="#' + anchor +  '"]');

		if (anchorLinks.length) {
			$('.fullpage-active').removeClass('fullpage-active');
			anchorLinks.addClass('fullpage-active');
		}
	}

	function headerHide() {
		if ($('.header_top_bg.header_trans-fixed').length) {
			$('.header_top_bg.header_trans-fixed').not('.fixed-dark').addClass('bg-fixed-color');
			$('.fixed-dark').addClass('bg-fixed-dark');
			$('.logo-hover, .header-button-scroll').show();
			$('.main-logo, .header-button-default').hide();
		}
		if ($('.right-menu.modern, .right-menu.aside-menu').length) {
			$('.fixed-header').addClass('fixed-header-scroll');
			$('.main-logo').hide();
			$('.logo-hover').fadeIn();
		}
	}

	function headerVisibile() {
		if ($('.header_top_bg.header_trans-fixed').length) {
			$('.header_top_bg.header_trans-fixed').not('.fixed-dark').removeClass('bg-fixed-color');
			$('.fixed-dark').removeClass('bg-fixed-dark');
			$('.logo-hover, .header-button-scroll').hide();
			$('.main-logo, .header-button-default').show();
		}
		if ($('.right-menu.modern, .right-menu.aside-menu').length) {
			$('.fixed-header').removeClass('fixed-header-scroll');
			$('.main-logo').fadeIn();
			$('.logo-hover').hide();
		}
	}

	function skills(section) {
		const skills_items = $(section).find('.skill-wrapper.linear, .skill-wrapper.simple_linear');

		if (skills_items.length) {
			skills_items.not('.active').each(function () {
				$(this).addClass('active');
				$(this).find('.skill').each(function () {
					var procent = $(this).attr('data-value');
					$(this).find('.active-line').css('width', procent + '%');
					$(this).find('.counter').countTo();
				}); // end each
			}); // end each
		}
	}

	function circleSkills(section) {
		const skills_items = $(section).find('.skill-wrapper.circle, .skill-wrapper.circle_horizontal');

		if (skills_items.length) {
			skills_items.not('.active').each(function () {
				$(this).addClass('active');
				$(this).find('.skill').each(function () {
					var procent = parseInt($(this).attr('data-value'), 10);
					var circle  = $(this).find('svg .bar');
					var r       = circle.attr('r');
					var c       = Math.PI * r * 2;
					if (procent < 0) {
						procent = 0;
					}
					if (procent > 100) {
						procent = 100;
					}
					var pct = ((100 - procent) / 100) * c;
					circle.css({strokeDashoffset: pct});

					$(this).find('.cont span').countTo();
				});
			});
		}
	}

	$(window).on('load resize', function () {
		fullPage();
	});
})(jQuery, window, document);
