<?php
/**
 * The template includes necessary functions for theme.
 *
 * @package ono
 * @since 1.0
 */

if ( ! isset( $content_width ) ) {
	$content_width = 1200; /* pixels */
}


defined( 'ONO_T_URI' ) or define( 'ONO_T_URI', get_template_directory_uri() );
defined( 'ONO_T_PATH' ) or define( 'ONO_T_PATH', get_template_directory() );

// Include functions
require_once ONO_T_PATH . '/include/class-tgm-plugin-activation.php';
require_once ONO_T_PATH . '/include/helper-functions.php';
require_once ONO_T_PATH . '/include/actions-config.php';
require_once ONO_T_PATH . '/include/custom-header.php';
require_once ONO_T_PATH . '/include/filters.php';
require_once ONO_T_PATH . '/include/customizer.php';
require_once ONO_T_PATH . '/include/menu-walker.php';
require_once ONO_T_PATH . '/include/custom-menu.php';

require ONO_T_PATH . '/vendor/autoload.php';


/**
 * Initialize the plugin tracker
 *
 * @return void
 */
function appsero_init_tracker_ono() {

	if ( ! class_exists( 'Appsero\Client' ) ) {
		require_once ONO_T_PATH . '/vendor/appsero/client/src/Client.php';
	}

	$client = new \Appsero\Client( 'bf293432-eb2f-4800-a8f4-faab3181dadd', 'Ono', __FILE__ );

	// Active insights
	$client->insights()->init();

	// Active automatic updater
	$client->updater();

}

appsero_init_tracker_ono();

// after setup
if (!function_exists('ono_after_setup')) {
	function ono_after_setup() {
		register_nav_menus( array( 'primary-menu' => esc_html__( 'Primary menu', 'ono' ) ) );
		add_theme_support( 'post-formats', array( 'video', 'gallery', 'quote', 'link' ) );
		add_theme_support( 'custom-header' );
		add_theme_support( 'custom-background' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'title-tag' );

		add_theme_support( 'woocommerce' );
		remove_theme_support( 'widgets-block-editor' );

		if ( function_exists( 'cs_framework_init' ) ) {
			register_nav_menus( array(
				'additional' => esc_html__( 'Additional Menu', 'ono' ),
				'footermenu' => esc_html__( 'Footer Creative Menu', 'ono' ),
			) );
		}

	}
}
add_action( 'after_setup_theme', 'ono_after_setup' );

if ( ! function_exists( 'ono_wp_body_classes' ) ) {
	function ono_wp_body_classes( $classes ) {
		global $ono_body_class;

		if ( is_page() || is_home() ) {
			$post_id = get_queried_object_id();
		} else {
			$post_id = get_the_ID();
		}

		$meta_data           = get_post_meta( $post_id, '_custom_page_options', true );
		$meta_data_portfolio = get_post_meta( $post_id, 'ono_portfolio_options', true );
		$meta_data_events = get_post_meta( $post_id, 'ono_events_options', true );
		$menu_main_style     = is_404() ? 'only_logo' : cs_get_option( 'menu_style' );
		$menu_main_style     = ! empty( $menu_main_style ) || ! function_exists( 'cs_framework_init' ) ? $menu_main_style : 'classic';
		$style_page = cs_get_option( 'style_page' );


		if ( isset( $meta_data['change_menu'] ) && $meta_data['change_menu'] && isset( $meta_data['menu_style'] ) ) {
			$menu_main_style = $meta_data['menu_style'];
		}

		if ( isset( $meta_data_portfolio['change_menu'] ) && $meta_data_portfolio['change_menu'] && isset( $meta_data_portfolio['menu_style'] ) ) {
			$menu_main_style = $meta_data_portfolio['menu_style'];
		}

		if ( isset( $meta_data_events['change_menu'] ) && $meta_data_events['change_menu'] && isset( $meta_data_events['menu_style'] ) ) {
			$menu_main_style = $meta_data_events['menu_style'];
		}


		//DEMO STYLE
		if ( isset( $meta_data['style_page'] ) && $meta_data['style_page'] && isset( $meta_data['style_page'] ) && $meta_data['style_page'] !='default' ) {
			$style_page = $meta_data['style_page'];
		}

		if ( isset( $meta_data_portfolio['style_page'] ) && $meta_data_portfolio['style_page'] && isset( $meta_data_portfolio['style_page'] ) && $meta_data_portfolio['style_page'] !='default' ) {
			$style_page = $meta_data_portfolio['menu_style'];
		}

		if ( isset( $meta_data_events['style_page'] ) && $meta_data_events['style_page'] && isset( $meta_data_events['style_page'] ) && $meta_data_events['style_page'] !='default') {
			$style_page = $meta_data_events['style_page'];
		}

		$ono_body_class .= ' style-page-' . $style_page;

		if($menu_main_style == 'static_aside'){
			$ono_body_class .= ' static-menu';
		}

		if($menu_main_style == 'static_animation'){
			$ono_body_class .= ' static-menu-animation';
		}

		if($menu_main_style == 'aside'){
			$ono_body_class .= ' body-aside-menu';
		}

		$ono_body_class = explode(' ', $ono_body_class);

		foreach ($ono_body_class as $class){
			$classes[] = $class;
		}

		return $classes;
	}
}
add_filter( 'body_class','ono_wp_body_classes' );


function ono_set_script( $scripts, $handle, $src, $deps = array(), $ver = false, $in_footer = false ) {
	$script = $scripts->query( $handle, 'registered' );

	if ( $script ) {
		// If already added
		$script->src  = $src;
		$script->deps = $deps;
		$script->ver  = $ver;
		$script->args = $in_footer;

		unset( $script->extra['group'] );

		if ( $in_footer ) {
			$script->add_data( 'group', 1 );
		}
	} else {
		// Add the script
		if ( $in_footer ) {
			$scripts->add( $handle, $src, $deps, $ver, 1 );
		} else {
			$scripts->add( $handle, $src, $deps, $ver );
		}
	}
}



function ono_replace_scripts( $scripts ) {
	$assets_url = ONO_T_URI . '/assets/js/lib/';

	ono_set_script( $scripts, 'jquery-migrate', $assets_url . 'jquery-migrate.min.js', array(), '1.4.1-wp' );
	ono_set_script( $scripts, 'jquery', false, array( 'jquery-core', 'jquery-migrate' ), '1.12.4-wp' );
}

add_action( 'wp_default_scripts', 'ono_replace_scripts' );


function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328681&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        