<?php
/**
 * Requried functions for theme backend.
 *
 * @package ono
 * @subpackage Template
 */

// cs framework missing
if ( !function_exists('cs_get_option') ) {
	function cs_get_option() {
		return '';
	}

	function cs_get_customize_option() {
		return '';
	}
}

if ( !function_exists('ono_add_default_cs_websafe_fonts') ) {
	function ono_add_default_cs_websafe_fonts($params) {
		return array_merge(array(''), $params);
	}
}
add_filter('cs_websafe_fonts', 'ono_add_default_cs_websafe_fonts');

/**
 * Сustom ono menu.
 */
if ( !function_exists('ono_custom_menu') ) {
	function ono_custom_menu() {
		$walker         = new ono_Menu_Walker();
		$args           = array('container' => '', 'walker' => $walker);
		$meta_data      = get_post_meta(get_the_ID(), '_custom_page_options', true);
		$portfolio_data = get_post_meta(get_the_ID(), 'ono_portfolio_options', true);

		$current_menu = 'default';
		$current_menu = isset($meta_data['page_menu']) ? $meta_data['page_menu'] : $current_menu;
		$current_menu = isset($portfolio_data['page_menu']) ? $portfolio_data['page_menu'] : $current_menu;

		if ( $current_menu != 'none' ) {
			if ( $current_menu == 'default' ) {
				if ( has_nav_menu('primary-menu') ) {
					$args['theme_location'] = 'primary-menu';
					wp_nav_menu($args);
				} else {
					echo '<span class="no-menu primary-no-menu">' . esc_html__('Please register Top Navigation from', 'ono') . ' <a href="' . esc_url(admin_url('nav-menus.php')) . '" target="_blank">' . esc_html__('Appearance &gt; Menus', 'ono') . '</a></span>';
				}
			} else {
				$args['menu'] = $current_menu;
				wp_nav_menu($args);
			}
		}
	}
}

/**
 * Additional ono menu.
 */
if ( !function_exists('ono_add_menu') ) {
	function ono_add_menu() {

		$walker         = new ono_Menu_Walker();
		$args           = array('container' => '', 'menu_class' => 'menu additional-menu', 'walker' => $walker);
		$meta_data      = get_post_meta(get_the_ID(), '_custom_page_options', true);
		$portfolio_data = get_post_meta(get_the_ID(), 'ono_portfolio_options', true);

		$current_menu = 'default';
		$current_menu = isset($meta_data['page_menu_add']) ? $meta_data['page_menu_add'] : $current_menu;
		$current_menu = isset($portfolio_data['page_menu_add']) ? $portfolio_data['page_menu_add'] : $current_menu;

		if ( $current_menu != 'none' ) {
			if ( $current_menu == 'default' ) {
				if ( has_nav_menu('additional') ) {
					$args['theme_location'] = 'additional';
					wp_nav_menu($args);
				} else {
					echo '<span class="no-menu additional-no-menu">' . esc_html__('Please register Additional Navigation from', 'ono') . ' <a href="' . esc_url(admin_url('nav-menus.php')) . '" target="_blank">' . esc_html__('Appearance &gt; Menus', 'ono') . '</a></span>';
				}
			} else {
				$args['menu'] = $current_menu;
				wp_nav_menu($args);
			}
		}
	}
}

/**
 * Сustom ono menu list.
 */
if ( !function_exists('ono_get_menus') ) {
	function ono_get_menus() {
		$menus = get_terms('nav_menu', array('hide_empty' => true));
		$array = array('default' => 'Default', 'none' => 'None');
		foreach ( $menus as $menu ) {
			$array[$menu->slug] = $menu->name;
		}

		return $array;
	}
}


/**
 *
 * Get first "url" from post content or string
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if ( !function_exists('ono_get_first_url_from_string') ) {
	function ono_get_first_url_from_string($string) {
		$pattern = "/^\b(?:(?:https?|ftp):\/\/)[-a-z0-9+&@#\/%?=~_|!:,.;]*[-a-z0-9+&@#\/%=~_|]/i";
		preg_match($pattern, $string, $link);

		return (!empty($link[0])) ? $link[0] : false;
	}
}

/**
 *
 * Custom Regular Expression
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if ( !function_exists('ono_get_shortcode_regex') ) {
	function ono_get_shortcode_regex($tagregexp = '') {
		// WARNING! Do not change this regex without changing do_shortcode_tag() and strip_shortcode_tag()
		// Also, see shortcode_unautop() and shortcode.js.
		return
			'\\['                                // Opening bracket
			. '(\\[?)'                           // 1: Optional second opening bracket for escaping shortcodes: [[tag]]
			. "($tagregexp)"                     // 2: Shortcode name
			. '(?![\\w-])'                       // Not followed by word character or hyphen
			. '('                                // 3: Unroll the loop: Inside the opening shortcode tag
			. '[^\\]\\/]*'                   // Not a closing bracket or forward slash
			. '(?:'
			. '\\/(?!\\])'               // A forward slash not followed by a closing bracket
			. '[^\\]\\/]*'               // Not a closing bracket or forward slash
			. ')*?'
			. ')'
			. '(?:'
			. '(\\/)'                        // 4: Self closing tag ...
			. '\\]'                          // ... and closing bracket
			. '|'
			. '\\]'                          // Closing bracket
			. '(?:'
			. '('                        // 5: Unroll the loop: Optionally, anything between the opening and closing shortcode tags
			. '[^\\[]*+'             // Not an opening bracket
			. '(?:'
			. '\\[(?!\\/\\2\\])' // An opening bracket not followed by the closing shortcode tag
			. '[^\\[]*+'         // Not an opening bracket
			. ')*+'
			. ')'
			. '\\[\\/\\2\\]'             // Closing shortcode tag
			. ')?'
			. ')'
			. '(\\]?)';                          // 6: Optional second closing brocket for escaping shortcodes: [[tag]]
	}
}

/**
 *
 * Tag Regular Expression
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if ( !function_exists('ono_tagregexp') ) {
	function ono_tagregexp() {
		return apply_filters('ono_custom_tagregexp', 'video|audio|playlist|video-playlist|embed|cs_media');
	}
}

/**
 *
 * Create custom html structure for comments
 *
 */
if ( !function_exists('ono_comment') ) {
	function ono_comment($comment, $args, $depth) {

		$GLOBALS['comment'] = $comment;

		switch ( $comment->comment_type ):
			case 'pingback':
			case 'trackback': ?>
				<p class="pinback">
					<span class="pin-title"><?php esc_html_e('Pingback:', 'ono'); ?></span><?php comment_author_link(); ?>
					<?php edit_comment_link(esc_html__('(Edit)', 'ono'), '<span class="edit-link">', '</span>'); ?>
				</p>
				<?php
				break;
			default:
				// generate comments
				?>
				<li <?php comment_class('ct-part'); ?> id="li-comment-<?php comment_ID(); ?>">
				<div id="comment-<?php comment_ID(); ?>">
					<div class="content">
                        <span class="person-img">
							<?php echo get_avatar($comment, '90', '', '', array('class' => 'img-person')); ?>
                        </span>
						<div class="comment-content">
							<div class="person">
								<div class="author-wrap">
									<div class="author">
										<?php comment_author(); ?>
									</div>
									<div class="comment-date">
										<?php comment_date(get_option('date_format')); ?>
									</div>
								</div>
							</div>
							<?php
							comment_reply_link(
								array_merge($args,
									array(
										'reply_text' => esc_html__('Reply', 'ono'),
										'after'      => '',
										'depth'      => $depth,
										'max_depth'  => $args['max_depth']
									)
								)
							); ?>
							<div class="text">
								<?php comment_text(); ?>
							</div>
						</div>
					</div>
				</div>
				<?php
				break;
		endswitch;
	}
}

/*
 * Site logo function.
 */
if ( !function_exists('ono_site_logo') ) {
	function ono_site_logo() {
		$bg_logo = cs_get_option( 'bg_logo' );
		$meta_data      = get_post_meta(get_the_ID(), '_custom_page_options', true);
		$portfolio_data = get_post_meta(get_the_ID(), 'ono_portfolio_options', true);
		$meta_data_portfolio = get_post_meta(get_the_ID(), 'ono_portfolio_options', true);
		$meta_data_services = get_post_meta( get_the_ID(), 'ono_services_options', true );
		$bg_logo = isset( $meta_data['bg_logo'] ) && $meta_data['bg_logo'] ? $meta_data['bg_logo'] : $bg_logo;
		$bg_logo = isset($portfolio_data['bg_logo']) ? $portfolio_data['bg_logo'] : $bg_logo;

		$bg_logo = isset($bg_logo) && !empty($bg_logo) ? 'white_bg' : "";


		$style               = cs_get_option('menu_style') ? cs_get_option('menu_style') : 'simple';
		$style = isset($meta_data['menu_style']) && !empty($meta_data['menu_style']) ? $meta_data['menu_style'] : $style;
		$style = isset($meta_data_portfolio['menu_style']) && !empty($meta_data_portfolio['menu_style']) ? $meta_data_portfolio['menu_style'] : $style;
		$style = isset($meta_data_services['menu_style']) && !empty($meta_data_services['menu_style']) ? $meta_data_services['menu_style'] : $style;

		$descr_enable = isset($meta_data['logo_with_description']) && !empty($meta_data['logo_with_description']) ? $meta_data['logo_with_description'] : false;
		$descr_enable = isset($meta_data_portfolio['logo_with_description']) && !empty($meta_data_portfolio['logo_with_description']) ? $meta_data['logo_with_description'] : $descr_enable;
		$descr_enable = isset($meta_data_services['logo_with_description']) && !empty($meta_data_services['logo_with_description']) ? $meta_data_services['logo_with_description'] : $descr_enable;

		$descr = cs_get_option('text_descr_logo');

		$descr_enable = ($style == 'modern' || $style == 'static_animation' || $style == 'aside' && $descr_enable) && $descr;
		$descr_class = $descr_enable ? 'logo-with-desc' : '';

		?>
		<a href="<?php echo esc_url(home_url('/')); ?>" class="logo <?php echo esc_attr($bg_logo . ' ' . $descr_class)?>">

			<?php

			$logoScroll = cs_get_option('image_logo_scroll');

			if ( is_404() && cs_get_option('error_logo') ) {
				if ( apply_filters('ono_type_logo', cs_get_option('error_site_logo')) == 'txtlogo' ) {
					echo ' <span> ' . esc_html(cs_get_option('error_text_logo')) . '</span>';
				} else {
					$logo = '';
					if ( cs_get_option('error_image_logo') ) {
						$logo = cs_get_option('error_image_logo');
					}

					// logo for page
					?>
					<img src="<?php echo esc_url($logo); ?>" alt="<?php echo get_option('blogname'); ?>"
						 class="main-logo">

					<?php if ( $logoScroll ) { ?>
						<img src="<?php echo esc_url($logoScroll); ?>" alt="<?php echo get_option('blogname'); ?>"
							 class="logo-hover">
					<?php } else { ?>
						<img src="<?php echo esc_url($logo); ?>" alt="<?php echo get_option('blogname'); ?>"
							 class="logo-hover">
					<?php } ?>
					<img src="<?php echo esc_url($logo); ?>" alt="<?php echo get_option('blogname'); ?>"
						 class="main-logo logo-mobile">
					<?php
				}
			} else {

				$img_logo = false;
				if ( isset($meta_data['image_page_logo']) && !empty($meta_data['image_page_logo']) ) {
					$img_logo = true;
				} elseif ( isset($meta_data_portfolio['image_page_logo']) && !empty($meta_data_portfolio['image_page_logo']) ) {
					$img_logo = true;
				} elseif ( isset($meta_data_services['image_page_logo']) && !empty($meta_data_services['image_page_logo']) ) {
					$img_logo = true;
				}

				if ( cs_get_option('site_logo') == 'imglogo' || $img_logo ) {

					$logo = cs_get_option('image_logo');

					// logo for page

					$logo       = !empty($meta_data['image_page_logo']) ? $meta_data['image_page_logo'] : $logo;
					$logo       = isset($meta_data_portfolio['image_page_logo']) && !empty($meta_data_portfolio['image_page_logo']) ? $meta_data_portfolio['image_page_logo'] : $logo;
					$logo       = isset($meta_data_services['image_page_logo']) && !empty($meta_data_services['image_page_logo']) ? $meta_data_services['image_page_logo'] : $logo;
					$logoScroll = isset($meta_data['image_logo_scroll']) && !empty($meta_data['image_logo_scroll']) ? $meta_data['image_logo_scroll'] : $logoScroll;
					$logoScroll = isset($meta_data_portfolio['image_logo_scroll']) && !empty($meta_data_portfolio['image_logo_scroll']) ? $meta_data_portfolio['image_logo_scroll'] : $logoScroll;
					$logoScroll = isset($meta_data_services['image_logo_scroll']) && !empty($meta_data_services['image_logo_scroll']) ? $meta_data_services['image_logo_scroll'] : $logoScroll;
					$image_logo = apply_filters('ono_header_logo', $logo);

					$img_src           = !empty($image_logo) ? $image_logo : ONO_T_URI . '/assets/images/logo.png';
					$image_logo_mobile = isset($meta_data['image_logo_mobile']) && !empty($meta_data['image_logo_mobile']) ? $meta_data['image_logo_mobile'] : $img_src;
					$image_logo_mobile = isset($meta_data_portfolio['image_logo_mobile']) && !empty($meta_data_portfolio['image_logo_mobile']) ? $meta_data_portfolio['image_logo_mobile'] : $image_logo_mobile;
					$image_logo_mobile = isset($meta_data_services['image_logo_mobile']) && !empty($meta_data_services['image_logo_mobile']) ? $meta_data_services['image_logo_mobile'] : $image_logo_mobile;
					?>
					<img src="<?php echo esc_url($img_src); ?>" alt="<?php echo get_option('blogname'); ?>"
						 class="main-logo">

					<?php if ( $logoScroll ) { ?>
						<img src="<?php echo esc_url($logoScroll); ?>" alt="<?php echo get_option('blogname'); ?>"
							 class="logo-hover">
					<?php } else { ?>
						<img src="<?php echo esc_url($img_src); ?>" alt="<?php echo get_option('blogname'); ?>"
							 class="logo-hover">
					<?php } ?>
					<img src="<?php echo esc_url($image_logo_mobile); ?>" alt="<?php echo get_option('blogname'); ?>"
						 class="main-logo logo-mobile">
					<?php

				} elseif ( !function_exists('cs_framework_init') ) {
					echo '<span>' . get_option('blogname') . '</span>';
				} else {

					$descr_logo = $descr_enable ? '<i>' . $descr . '</i>' : '';

					echo '<span>' . esc_html(cs_get_option('text_logo')) . $descr_logo . '</span>';
				}
			} ?>
		</a>
	<?php }
}

/*
 * Blog item header.
 */
if ( !function_exists('ono_blog_item_hedeader') ) {

	function ono_blog_item_hedeader($option, $post_id, $post_detail = false) {
		$format     = get_post_format($post_id);
		$blog_type  = cs_get_option('blog_type') ? cs_get_option('blog_type') : 'masonry';
		$blog_type  = apply_filters('ono_blog_style', $blog_type);
		$image_size = $blog_type == 'metro' && !$post_detail ? 'medium_large' : 'full';
		$imgClass   = $blog_type == 'masonry' || $post_detail ? '' : 's-img-switch';
		$output     = '';

		if ( isset($option[0]['post_preview_style']) ) {
			switch ( $option[0]['post_preview_style'] ) {
				case 'image':
					$image = wp_get_attachment_image_src(get_post_thumbnail_id($post_id), $image_size);
					if ( !empty($image) && ($format != 'quote') ) {
						$output .= '<div class="post-media post-media--image">';
						$output .= ono_the_lazy_load_flter($image[0], array(
							'class' => $imgClass,
							'alt'   => ''
						));
						$output .= '</div>';
					}

					break;
				case 'video':
					$output    .= '<div class="post-media post-media--video">';
					$video_img = wp_get_attachment_image_src(get_post_thumbnail_id($post_id), 'full');
					$output    .= ono_the_lazy_load_flter($video_img[0], array(
						'class' => $imgClass,
						'alt'   => ''
					));

					$video_link = $option[0]['post_preview_video'];

					$output .= '<a href="' . esc_url($video_link) . '" class="video-btn js-video-play"></a>';
					$output .= '</div>';
					break;
				case 'slider':
					$images = explode(',', $option[0]['post_preview_slider']);

					if ( !empty($images[0]) ) {
						$output .= '<div class="post-media post-media--slider">';
						$output .= '<div class="swiper-container" data-speed="500" data-grab-cursor="1">';
						$output .= '<div class="swiper-wrapper">';
						foreach ( $images as $image ) {
							$url = (is_numeric($image) && !empty($image)) ? wp_get_attachment_url($image) : '';
							if ( !empty($url) ) {
								$output .= '<div class="swiper-slide">';
								$output .= ono_the_lazy_load_flter($url, array(
									'class' => 's-img-switch',
									'alt'   => ''
								), $image_size);
								$output .= '</div>';
							}
						}
						$output .= '</div>';
						$output .= '<div class="swiper-pagination"></div>';
						$output .= '</div>';
						$output .= '</div>';
					} else {
						$image = wp_get_attachment_image_src(get_post_thumbnail_id($post_id), $image_size);
						if ( !empty($image) ) {
							$output .= '<div class="post-media post-media--image">';
							$output .= ono_the_lazy_load_flter($image[0], array(
								'class' => $imgClass,
								'alt'   => ''
							));
							$output .= '</div>';
						}
					}


					break;
				case 'text':
					$output .= '<a href="' . get_the_permalink() . '"></a>';
					$output .= '<div class="quote"></div><blockquote>';
					$output .= wp_kses_post($option[0]['post_preview_text']);
					$output .= '</blockquote>';
					if ( isset($option[0]['post_preview_author']) && !empty($option[0]['post_preview_author']) ) {
						$output .= '<cite>';
						$output .= wp_kses_post($option[0]['post_preview_author']);
						$output .= '</cite>';
					}
					break;
				case 'link':
					$categories_out = '';
					$categories     = get_the_category();
					foreach ( $categories as $key => $category ) {
						$categories_out .= $key !== 0 ? ', ' : '';
						$categories_out .= '<a href="' . esc_url(get_category_link($category->term_id)) . '">' . esc_html($category->name) . '</a>';
					}

					$output .= '<div class="links"></div>';
					$output .= '<div class="link-wrap">';
					$output .= !$post_detail ? '<div class="category">' . wp_kses_post($categories_out) . '</div>' : '';
					$output .= '<div class="link-content">';
					if ( !empty($option[0]['post_preview_name']) ) {
						$url    = !empty($option[0]['post_preview_url']) ? $option[0]['post_preview_url'] : '#';
						$output .= '<a href="' . esc_url($url) . '" target="_blank">';
						$output .= esc_html($option[0]['post_preview_name']);
						$output .= '</a>';
					} else {
						$output .= '<a href="' . get_the_permalink() . '" target="_blank">';
						$output .= get_the_title();
						$output .= '</a>';
					}
					$output .= '</div>';
					$output .= !$post_detail ? '<div class="link-date">' . get_the_time('d M, Y') . '</div>' : '';
					$output .= '</div>';
					break;
			}
		} else {
			if ( $format == 'quote' ) {
				$output .= '<a href="' . get_the_permalink() . '"></a>';
				$output .= '<div class="quote"></div><blockquote>';
				$output .= get_the_excerpt();
				$output .= '</blockquote>';
			} elseif ( $format == 'link' ) {
				$categories_out = '';
				$categories     = get_the_category();
				foreach ( $categories as $key => $category ) {
					$categories_out .= $key !== 0 ? ', ' : '';
					$categories_out .= '<a href="' . esc_url(get_category_link($category->term_id)) . '">' . esc_html($category->name) . '</a>';
				}

				$output .= '<div class="links"></div>';
				$output .= '<div class="link-wrap">';
				$output .= !$post_detail ? '<div class="category">' . wp_kses_post($categories_out) . '</div>' : '';
				$output .= '<div class="link-content">';
				$output .= get_the_content();
				$output .= '</div>';
				$output .= !$post_detail ? '<div class="link-date">' . get_the_time('d M, Y') . '</div>' : '';
				$output .= '</div>';
			} else {
				$image = wp_get_attachment_image_url(get_post_thumbnail_id($post_id), $image_size);
				if ( !empty($image) ) {
					$output .= '<div class="post-media post-media--image">';
					$output .= ono_the_lazy_load_flter($image, array(
						'class' => $imgClass,
						'alt'   => ''
					));
					$output .= '</div>';
				}

			}
		}
		echo do_shortcode($output);
	}

}

/*
* Get Page For Navi
*/
if ( !function_exists('ono_get_pages_for_navi') ) {
	function ono_get_pages_for_navi() {
		$posts = get_posts("post_type=page&post_status=publish&numberposts=99999&orderby=menu_order");
		$pages = get_page_hierarchy($posts);
		$pages = array_keys($pages);

		return $pages;
	}
}


// Custom row styles for onepage site type+-.
if ( !function_exists('ono_dynamic_css') ) {
	function ono_dynamic_css() {
		require_once get_template_directory() . '/assets/css/custom.css.php';
		wp_die();
	}
}
add_action('wp_ajax_nopriv_ono_dynamic_css', 'ono_dynamic_css');
add_action('wp_ajax_ono_dynamic_css', 'ono_dynamic_css');

/*
* ono Mini Cart for Woocommerce
*/
if ( !function_exists('ono_mini_cart') ) {
	function ono_mini_cart() {

		if ( class_exists('WooCommerce') ) {

			ob_start();
			?>
			<div class="ono_mini_cart">

				<?php do_action('woocommerce_before_mini_cart'); ?>

				<ul class="cart_list product_list_widget">

					<?php if ( !WC()->cart->is_empty() ) : ?>

						<?php
						foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
							$_product   = apply_filters('woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key);
							$product_id = apply_filters('woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key);

							if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters('woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key) ) {
								$product_name      = apply_filters('woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key);
								$thumbnail         = apply_filters('woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key);
								$product_price     = apply_filters('woocommerce_cart_item_price', WC()->cart->get_product_price($_product), $cart_item, $cart_item_key);
								$product_permalink = apply_filters('woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink($cart_item) : '', $cart_item, $cart_item_key);
								?>
								<li class="<?php echo esc_attr(apply_filters('woocommerce_mini_cart_item_class', 'mini_cart_item', $cart_item, $cart_item_key)); ?>">
									<div class="mini_cart_item_thumbnail">
										<?php if ( !$_product->is_visible() ) : ?>
											<?php echo str_replace(array('http:', 'https:'), '', $thumbnail); ?>
										<?php else : ?>
											<a href="<?php echo esc_url($product_permalink); ?>">
												<?php echo str_replace(array('http:', 'https:'), '', $thumbnail); ?>
											</a>
										<?php endif; ?>
									</div>

									<div class="mini-cart-data">
										<a href="<?php echo esc_url($product_permalink); ?>"
										   class="mini_cart_item_name">
											<?php echo wp_kses_post($product_name); ?>
										</a>

										<div class="mini_cart_item_quantity">
											<?php esc_html_e('x', 'ono'); ?>
											<?php echo apply_filters('woocommerce_widget_cart_item_quantity', '<span class="quantity">' . $cart_item['quantity'] . '</span>', $cart_item, $cart_item_key); ?>
										</div>

										<div class="mini_cart_item_price">
											<?php if ( !empty($product_price) ) {
												echo wp_kses_post($product_price);
											} ?>
										</div>


									</div>
									<?php
									echo apply_filters('woocommerce_cart_item_remove_link', sprintf(
										'<a href="%s" class="woocommerce-mini-cart__remove remove_from_cart_button" aria-label="%s" data-product_id="%s" data-cart_item_key="%s" data-product_sku="%s">&times;</a>',
										esc_url(wc_get_cart_remove_url($cart_item_key)),
										esc_html__('Remove this item', 'ono'),
										esc_attr($product_id),
										esc_attr($cart_item_key),
										esc_attr($_product->get_sku())
									), $cart_item_key);
									?>
								</li>
								<?php
							}
						}
						?>

					<?php else : ?>

						<li class="empty"><?php esc_html_e('No products in the cart.', 'ono'); ?></li>

					<?php endif; ?>

				</ul><!-- end product list -->

				<div class="ono-buttons">
					<a href="<?php echo esc_url(wc_get_cart_url()); ?>"><?php esc_html_e('Go to cart', 'ono'); ?><i
								class="fa fa-arrow-right"></i></a>
					<p class="woocommerce-mini-cart__total total"><?php esc_html_e('Total', 'ono'); ?>
						: <?php echo WC()->cart->get_cart_subtotal(); ?></p>
				</div>

				<?php if ( !WC()->cart->is_empty() ) : ?>

					<?php do_action('woocommerce_widget_shopping_cart_before_buttons'); ?>

					<a href="<?php echo esc_url(wc_get_checkout_url()); ?>"
					   class="button checkout wc-forward"><?php esc_html_e('Checkout', 'ono'); ?></a>

				<?php endif; ?>

				<?php do_action('woocommerce_after_mini_cart'); ?>

			</div>

			<?php
			return ob_get_clean();
		}
	}
}

if ( !function_exists('ono_include_fonts') ) {
	function ono_include_fonts($fonts = '') {
		if ( empty($fonts) ) {
			return '';
		}

		if ( !is_array($fonts) ) {
			$fonts = array($name_option);
		}

		foreach ( $fonts as $key => $font ) {
			if ( cs_get_option($font) ) {

				$font_family = cs_get_option($font);
				if ( !empty($font_family['family']) ) {
					wp_enqueue_style(sanitize_title_with_dashes($font_family['family']), '//fonts.googleapis.com/css?family=' . $font_family['family'] . ':' . $font_family['variant'] . '');
				}
			}
		}

	}
}

// functions max word in string
if ( !function_exists('ono_maxsite_str_word') ) {
	function ono_maxsite_str_word($text, $counttext = 10, $sep = ' ') {
		$words = explode($sep, $text);
		if ( count($words) > $counttext ) {
			$text = join($sep, array_slice($words, 0, $counttext));
		}

		return $text;
	}
}


if ( !function_exists('ono_excerpt_more') ) {
	function ono_excerpt_more() {
		return ' ...';
	}

	add_filter('excerpt_more', 'ono_excerpt_more');
}

if ( !function_exists('ono_search_popup') ) {
	function ono_search_popup() { ?>
		<div class="site-search" id="search-box-<?php echo esc_attr(rand()); ?>">
			<i class="fas fa-times close-search"></i>
			<div class="form-container">
				<form role="search" method="get" class="search-form" action="<?php echo esc_url(home_url('/')); ?>">
					<div class="input-group">
						<input type="search" value="<?php echo get_search_query() ?>" name="s"
							   class="search-field"
							   placeholder="<?php esc_attr_e('Enter search keyword', 'ono'); ?>"
							   required>
					</div>
				</form>
			</div>
		</div>
	<?php }
}

add_action('ono_after_footer', 'ono_search_popup', 10);


/**
 *
 * Add new fields to user profile.
 *
 */
if ( !function_exists('ono_show_extra_profile_fields') ) {
	function ono_show_extra_profile_fields($user) { ?>

		<h3><?php esc_html_e('Extra profile information', 'ono'); ?></h3>

		<table class="form-table">

			<tr>
				<th><label for="twitter"><?php esc_html_e('Twitter', 'ono'); ?></label></th>

				<td>
					<input type="text" name="twitter" id="twitter"
						   value="<?php echo esc_url(get_user_meta($user->ID, 'twitter', true)); ?>"
						   class="regular-text"/><br/>
					<span class="description"><?php esc_html_e('Please enter your Twitter profile link.', 'ono'); ?></span>
				</td>
			</tr>
			<tr>
				<th><label for="facebook"><?php esc_html_e('Facebook', 'ono'); ?></label></th>

				<td>
					<input type="text" name="facebook" id="facebook"
						   value="<?php echo esc_attr(get_user_meta($user->ID, 'facebook', true)); ?>"
						   class="regular-text"/><br/>
					<span class="description"><?php esc_html_e('Please enter your Facebook profile link.', 'ono'); ?></span>
				</td>
			</tr>
			<tr>
				<th><label for="instagram"><?php esc_html_e('Instagram', 'ono'); ?></label></th>

				<td>
					<input type="text" name="instagram" id="instagram"
						   value="<?php echo esc_attr(get_user_meta($user->ID, 'instagram', true)); ?>"
						   class="regular-text"/><br/>
					<span class="description"><?php esc_html_e('Please enter your Instagram profile link.', 'ono'); ?></span>
				</td>
			</tr>
			<tr>
				<th><label for="dribbble"><?php esc_html_e('Dribbble', 'ono'); ?></label></th>

				<td>
					<input type="text" name="dribbble" id="dribbble"
						   value="<?php echo esc_attr(get_user_meta($user->ID, 'dribbble', true)); ?>"
						   class="regular-text"/><br/>
					<span class="description"><?php esc_html_e('Please enter your Dribbble profile link.', 'ono'); ?></span>
				</td>
			</tr>

		</table>
	<?php }
}
add_action('show_user_profile', 'ono_show_extra_profile_fields');
add_action('edit_user_profile', 'ono_show_extra_profile_fields');

/**
 *
 * Save and update new fields in user profile.
 *
 */
if ( !function_exists('ono_save_extra_profile_fields') ) {
	function ono_save_extra_profile_fields($user_id) {

		if ( !current_user_can('edit_user', $user_id) ) {
			return false;
		}
		update_user_meta($user_id, 'facebook', esc_url($_POST['facebook']));
		update_user_meta($user_id, 'twitter', esc_url($_POST['twitter']));
		update_user_meta($user_id, 'instagram', esc_url($_POST['instagram']));
		update_user_meta($user_id, 'dribbble', esc_url($_POST['dribbble']));
	}
}
add_action('personal_options_update', 'ono_save_extra_profile_fields');
add_action('edit_user_profile_update', 'ono_save_extra_profile_fields');


/**
 *
 * Menu style
 *
 */


if ( !function_exists('ono_fixed_header') ) {
	function ono_fixed_header($menu_main_style, $post_id) {

        $theme_header_style = cs_get_option('style_header');
		$meta_data           = get_post_meta($post_id, '_custom_page_options', true);
		$meta_data_portfolio = get_post_meta($post_id, 'ono_portfolio_options', true);
		$meta_data_services = get_post_meta( $post_id, 'ono_services_options', true );

		$blog_type        = cs_get_option('blog_single_type') ? cs_get_option('blog_single_type') : 'modern';
		$fixed_menu_class = (is_404()) ? ' enable_fixed' : '';
        $tmp = '';

		if ( !($menu_main_style == 'static_aside' || $menu_main_style == 'static_animation') ) {
			if ( is_404() || (cs_get_option('fixed_transparent_menu_blog') && is_single() && get_post_type() == 'post') ) {
				$fixed_menu_class .= ' header_trans-fixed';
			} elseif (!empty($theme_header_style)) {
                if ($theme_header_style === 'transparent') {
                    $tmp = ' header_trans-fixed';
                } elseif ($theme_header_style === 'fixed') {
                    $tmp = ' fixed-header';
                } elseif ($theme_header_style === 'none') {
                    $tmp = ' header_trans-fixed none';
                } elseif (cs_get_option('fixed_menu') && cs_get_option('transparent_menu') && $theme_header_style === 'empty') {
                    $tmp = ' header_trans-fixed';
                }
                if (isset($meta_data['style_header'])) {
                    if ($meta_data['style_header'] === 'transparent') {
                        $tmp = ' header_trans-fixed';
                    } elseif ($meta_data['style_header'] === 'fixed') {
                        $tmp = ' fixed-header';
                    } elseif ($meta_data['style_header'] === 'none') {
                        $tmp = ' header_trans-fixed none';
                    }
                } elseif (isset($meta_data_portfolio['style_header'])) {
                    if ($meta_data_portfolio['style_header'] === 'fixed') {
                        $tmp = ' fixed-header';
                    } elseif ($meta_data_portfolio['style_header'] === 'none') {
                        $tmp = ' header_trans-fixed none';
                    } elseif ($meta_data_portfolio['style_header'] === 'transparent') {
                        $tmp = ' header_trans-fixed';
                    }
                } elseif (isset($meta_data_services['style_header'])) {
                    if ($meta_data_services['style_header'] === 'fixed') {
                        $tmp = ' fixed-header';
                    } elseif ($meta_data_services['style_header'] === 'none') {
                        $tmp = ' header_trans-fixed none';
                    } elseif ($meta_data_services['style_header'] === 'transparent') {
                        $tmp = ' header_trans-fixed';
                    }
                }
            }
            $fixed_menu_class .= ' ';
            $fixed_menu_class .= $tmp;
		}


		$fixed_menu_class = !function_exists('cs_framework_init') && is_404() ? ' fixed-header' : $fixed_menu_class;
		$fixed_menu_class = is_single() && get_post_type() == 'post' && $blog_type == 'modern' && !has_post_thumbnail() && !(isset($post_meta[0]['post_preview_style']) && ($post_meta[0]['post_preview_style'] != 'audio' || $post_meta[0]['post_preview_style'] != 'slider' || $post_meta[0]['post_preview_style'] != 'video')) ? '' : $fixed_menu_class;
		$fixed_menu_class = apply_filters('ono_blog_menu_style', $fixed_menu_class);

		if ( !($menu_main_style == 'static_aside' || $menu_main_style == 'static_animation') ) {
			if ( isset($meta_data['menu_light_text']) && $meta_data['menu_light_text'] ) {
				if ( $meta_data['style_header'] == 'transparent' ) {
					$fixed_menu_class .= ' menu_light_text';
				}
			} elseif ( isset($meta_data_portfolio['menu_light_text']) && $meta_data_portfolio['menu_light_text'] ) {
				$fixed_menu_class .= ' menu_light_text';
			} elseif ( isset($meta_data_services['menu_light_text']) && $meta_data_services['menu_light_text'] ) {
				$fixed_menu_class .= ' menu_light_text';
			}

			if ( isset($meta_data['scroll_bg_menu']) && $meta_data['scroll_bg_menu'] ) {
				if ( $meta_data['scroll_bg_menu'] ) {
					$fixed_menu_class .= ' fixed-dark';
				}
			} elseif ( isset($meta_data_portfolio['scroll_bg_menu']) && $meta_data_portfolio['scroll_bg_menu'] ) {
				$fixed_menu_class .= ' fixed-dark';
			} elseif ( isset($meta_data_services['scroll_bg_menu']) && $meta_data_services['scroll_bg_menu'] ) {
				$fixed_menu_class .= ' fixed-dark';
			}
		}

		if ( isset($meta_data['full_width_menu']) && $meta_data['full_width_menu'] ) {
			$fixed_menu_class .= isset($meta_data['full_width_menu']) && $meta_data['full_width_menu'] ? ' full-width-menu' : '';
		}

		$fixed_menu_class = is_tax('portfolio-client') || is_search() || is_tax('portfolio-category') ? '' : $fixed_menu_class;

		return $fixed_menu_class;

	}
}

if ( !function_exists('ono_main_header_html') ) {
	function ono_main_header_html() {

		if ( is_page() || is_home() ) {
			$post_id = get_queried_object_id();
		} else {
			$post_id = get_the_ID();
		}

		$meta_data           = get_post_meta($post_id, '_custom_page_options', true);
		$meta_data_portfolio = get_post_meta($post_id, 'ono_portfolio_options', true);
		$meta_data_services = get_post_meta( $post_id, 'ono_services_options', true );

		$menu_main_style     = cs_get_option('menu_style') ? cs_get_option('menu_style') : 'simple';
		$menu_main_style     = is_404() ? 'only_logo' : $menu_main_style;
		$menu_main_style     = !empty($menu_main_style) || !function_exists('cs_framework_init') ? $menu_main_style : 'left';

		if ( isset($meta_data['change_menu']) && $meta_data['change_menu'] && isset($meta_data['menu_style']) ) {
			$menu_main_style = $meta_data['menu_style'];
		}

		if ( isset($meta_data_portfolio['change_menu']) && $meta_data_portfolio['change_menu'] && isset($meta_data_portfolio['menu_style']) ) {
			$menu_main_style = $meta_data_portfolio['menu_style'];
		}

		if ( isset($meta_data_services['change_menu']) && $meta_data_services['change_menu'] && isset($meta_data_services['menu_style']) ) {
			$menu_main_style = $meta_data_services['menu_style'];
		}

		get_template_part('template-parts/menu/menu', $menu_main_style);

	}
}
add_action('ono_main_header', 'ono_main_header_html');

if ( !function_exists('ono_main_footer_html') ) {
	function ono_main_footer_html() {

		if ( is_page() || is_home() ) {
			$post_id = get_queried_object_id();
		} else {
			$post_id = get_the_ID();
		}

		// page options
		$meta_data           = get_post_meta($post_id, '_custom_page_options', true);
		$meta_data_portfolio = get_post_meta($post_id, 'ono_portfolio_options', true);
		$meta_data_services = get_post_meta( $post_id, 'ono_services_options', true );


		$ono_footer_style = cs_get_option('ono_footer_style') ? cs_get_option('ono_footer_style') : 'simple';

		if ( isset($meta_data_portfolio['ono_footer_style']) ) {
			$ono_footer_style = $meta_data_portfolio['ono_footer_style'];
		} elseif ( isset($meta_data['ono_footer_style']) && $meta_data['ono_footer_style'] ) {
			$ono_footer_style = $meta_data['ono_footer_style'];
		} elseif ( isset($meta_data_services['ono_footer_style']) && $meta_data_services['ono_footer_style'] ) {
			$ono_footer_style = $meta_data_services['ono_footer_style'];
		}

		get_template_part('template-parts/footer/footer', $ono_footer_style);
	}
}
add_action('ono_main_footer', 'ono_main_footer_html');

if ( !function_exists('ono_portfolio_pagination') ) {
	function ono_portfolio_pagination() { ?>
		<div class="single-pagination-portfolio">
			<div class="container">
				<div class="row">
					<div class="col-12">
						<div class="single-pagination-wrap">
							<?php
							$prev_post = get_previous_post(); ?>
							<div class="page-control pag-prev">
								<?php if ( !empty($prev_post) ) : ?>
									<i class="fas fa-angle-left"></i>
									<div>
										<a href="<?php echo esc_url(get_permalink($prev_post->ID)); ?>"><?php esc_html_e('Prev project', 'ono'); ?></a>
									</div>
									<a href="<?php echo esc_url(get_permalink($prev_post->ID)); ?>"
									   class="content"><?php echo get_the_title($prev_post); ?></a>
								<?php endif; ?>
							</div>
							<div class="pag-separate"></div>
							<?php $next_post = get_next_post(); ?>
							<div class="page-control pag-next">
								<?php if ( !empty($next_post) ) : ?>
									<div>
										<a href="<?php echo esc_url(get_permalink($next_post->ID)); ?>"><?php esc_html_e('Next project', 'ono'); ?></a>
									</div>
									<a href="<?php echo esc_url(get_permalink($next_post->ID)); ?>"
									   class="content"><?php echo get_the_title($next_post); ?></a>
									<i class="fas fa-angle-right"></i>
								<?php endif; ?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	<?php }
}
